/** @file
 *
 * @brief Fonctions de gestion du tlmtre
 * @date 2003-2004
 * @author L'quipe Unitec, http://ae.utbm.fr/unitec/
 * @note Code ralis pour la Coupe de France de Robotique 2004
 */

#include "x24x_inc.h"
#include "global.h"

/** Initialisation du tlmtre
 *
 * Cette fonction initialise le tlmtre et la conversion
 * analogique/numrique ncessaire  la conversion des valeurs reues
 * de celui-ci.
 */
void init_telemetre(void)
{
  SCSR1 = SCSR1 | 0x80;
  
  /* Reset convertisseur analogique numrique */
  ADCTRL1 = 0x4000;
  
  /* Mise en marche */
  ADCTRL1 = 0x3000;
  
  /* Nombre max de conversion analog => numerique */
  MAXCONV = 0x7;
  
  /* Choix de la voie de conversion */
  CHSELSEQ1 = 0x1;
 
  ADCTRL2 = 0x4000; 
}
 
/** Rcupration d'une valeur du tlmtre
 *
 * Cette fonction lance une conversion analogique/numrique de la
 * valeur courante du tlmtre et la retourne
 *
 * @return La valeur entire reue par le tlmtre
 */
int valeur_telemetre(void)
{ 
  int val;
  
  /* Demande de conversion */
  ADCTRL2 = 0x2000;
  
  /* Attente de la conversion */
  while(ADCTRL2 & 0x1000);
  
  /* Rcupration du rsultat */
  val = RESULT0;
  
  /* La valeur est stocke dans les 10 bits de poids fort de la valeur
     sur 16 bits renvoye par le convertisseur A/N */
  val = val >> 6;
  
  return val;
}
